Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src\zapy\api\__init__.py | 1 | 0 | 0 | 0 | 0 | 100%
src\zapy\api\bootstrapper.py | 6 | 3 | 0 | 0 | 0 | 50%
src\zapy\api\connection.py | 29 | 29 | 0 | 6 | 0 | 0%
src\zapy\api\deps\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src\zapy\api\deps\socketio.py | 7 | 0 | 0 | 0 | 0 | 100%
src\zapy\api\exceptions.py | 17 | 11 | 0 | 6 | 0 | 26%
src\zapy\api\models.py | 53 | 0 | 0 | 0 | 0 | 100%
src\zapy\api\server.py | 15 | 0 | 0 | 0 | 0 | 100%
src\zapy\api\v1\__init__.py | 3 | 0 | 0 | 0 | 0 | 100%
src\zapy\api\v1\api_requests.py | 35 | 6 | 0 | 10 | 0 | 82%
src\zapy\api\v1\api_server.py | 24 | 0 | 0 | 2 | 0 | 100%
src\zapy\api\v1\api_store.py | 10 | 0 | 0 | 2 | 0 | 100%
src\zapy\base\__init__.py | 2 | 0 | 0 | 0 | 0 | 100%
src\zapy\base\auto.py | 2 | 0 | 0 | 0 | 0 | 100%
src\zapy\base\exceptions.py | 12 | 3 | 0 | 2 | 0 | 79%
src\zapy\base\models.py | 7 | 0 | 0 | 0 | 0 | 100%
src\zapy\cli.py | 25 | 25 | 0 | 2 | 0 | 0%
src\zapy\requests\__init__.py | 5 | 0 | 0 | 0 | 0 | 100%
src\zapy\requests\context.py | 23 | 0 | 0 | 6 | 0 | 100%
src\zapy\requests\converter.py | 93 | 1 | 0 | 46 | 1 | 99%
src\zapy\requests\exceptions.py | 29 | 9 | 0 | 8 | 0 | 70%
src\zapy\requests\file_loader.py | 12 | 0 | 0 | 2 | 0 | 100%
src\zapy\requests\hooks.py | 26 | 0 | 0 | 2 | 0 | 100%
src\zapy\requests\models.py | 58 | 2 | 0 | 12 | 1 | 93%
src\zapy\requests\requester.py | 96 | 11 | 0 | 22 | 3 | 88%
src\zapy\store\__init__.py | 2 | 0 | 0 | 0 | 0 | 100%
src\zapy\store\attr.py | 29 | 5 | 0 | 16 | 3 | 78%
src\zapy\store\context.py | 7 | 0 | 0 | 0 | 0 | 100%
src\zapy\store\manager.py | 74 | 44 | 0 | 20 | 0 | 38%
src\zapy\templating\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src\zapy\templating\eval.py | 32 | 6 | 0 | 6 | 0 | 84%
src\zapy\templating\templating.py | 31 | 3 | 0 | 8 | 1 | 90%
src\zapy\templating\traceback.py | 47 | 16 | 0 | 6 | 1 | 60%
src\zapy\test\__init__.py | 4 | 0 | 0 | 0 | 0 | 100%
src\zapy\test\assertion.py | 18 | 0 | 0 | 4 | 0 | 100%
src\zapy\test\models.py | 6 | 0 | 0 | 0 | 0 | 100%
src\zapy\test\test_case.py | 9 | 2 | 0 | 2 | 0 | 64%
src\zapy\test\test_runner.py | 24 | 0 | 0 | 8 | 0 | 100%
src\zapy\utils\__init__.py | 1 | 0 | 0 | 0 | 0 | 100%
src\zapy\utils\functools.py | 21 | 4 | 0 | 10 | 4 | 74%
src\zapy\utils\module.py | 50 | 18 | 0 | 14 | 1 | 61%
src\zapy\utils\singleton.py | 11 | 0 | 0 | 4 | 0 | 100%
tests\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests\api\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests\api\test_api_v1.py | 51 | 0 | 0 | 6 | 0 | 100%
tests\assets\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests\assets\setup\__init__.py | 1 | 1 | 0 | 0 | 0 | 0%
tests\assets\setup\setup_store.py | 3 | 3 | 0 | 0 | 0 | 0%
tests\request\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests\request\test_request_chain.py | 20 | 0 | 0 | 8 | 0 | 100%
tests\request\test_request_converter.py | 97 | 0 | 0 | 0 | 0 | 100%
tests\request\test_request_script.py | 65 | 0 | 0 | 16 | 0 | 100%
tests\templating\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests\templating\test_eval.py | 4 | 0 | 0 | 0 | 0 | 100%
Total | 1197 | 202 | 0 | 256 | 15 | 82%

No items found using the specified filter.